@@ -8,29 +8,29 @@ extends 'API::Github::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Github (Perl)',
 );
 
 has username => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has token => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 3,
 );
 
@@ -134,7 +134,7 @@ API::Github - Perl 5 API wrapper for Github
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -391,9 +391,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $github->action('head', %args);   # HEAD request
-    $github->action('optons', %args); # OPTIONS request
-    $github->action('patch', %args);  # PATCH request
+    $github->action('head', %args);    # HEAD request
+    $github->action('options', %args); # OPTIONS request
+    $github->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
